AeoLiS
======

AeoLiS is a process-based model for simulating aeolian sediment
transport in situations where supply-limiting factors are important,
like in coastal environments. Supply-limitations currently supported
are soil moisture contents, sediment sorting and armouring, bed slope
effects, air humidity and roughness elements.

The maintenance and development is done by the AEOLIS developer team:
Current members are:
`Bart van Westen <Bart.vanWesten@deltares.nl>`_ at Deltares, 
`Nick Cohn <nick.cohn@usace.army.mil>`_ at U.S. Army Engineer Research and Development Center (ERDC), 
`Sierd de Vries <Sierd.deVries@tudelft.nl>`_ (founder) at Delft University of Technology,
`Christa van IJzendoorn <C.O.vanIJzendoorn@tudelft.nl>`_ at Delft University of Technology,
`Caroline Hallin <E.C.Hallin@tudelft.nl>`_ at Delft University of Technology,
`Glenn Strypsteen <glenn.strypsteen@kuleuven.be>`_ at Katholieke Universiteit Leuven and
`Janelle Skaden <Janelle.E.Skaden@usace.army.mil>`_ at U.S. Army Engineer Research and Development Center (ERDC).

Previous members are:
`Bas Hoonhout <bas@hoonhout.com>`_ (founder), Tom Pak, Pieter Rauwoens and Lisa Meijer